@@ -12,6 +12,7 @@ from sqlalchemy.engine import Engine
 from modelhub.aggregate import Aggregate
 from modelhub.map import Map
 from modelhub.models.logistic_regression import LogisticRegression
+from modelhub.models.funnel_discovery import FunnelDiscovery
 from modelhub.series.series_objectiv import MetaBase
 from sql_models.constants import NotSet
 from sql_models.util import is_bigquery
@@ -265,10 +266,17 @@ class ModelHub:
 
     def get_logistic_regression(self, *args, **kwargs) -> LogisticRegression:
         """
-        Return an instance of the :py:class:`LogisticRegression` from the model hub.
+        Return an instance of the :py:class:`modelhub.LogisticRegression` class from the model hub.
 
         All parameters passed to this function are passed to the constructor of the LogisticRegression
         model.
         """
 
         return LogisticRegression(*args, **kwargs)
+
+    def get_funnel_discovery(self) -> FunnelDiscovery:
+        """
+        Return an instance of the :py:class:`modelhub.FunnelDiscovery` class from the model hub.
+        """
+
+        return FunnelDiscovery()
