@@ -4,11 +4,12 @@ Copyright 2021 Objectiv B.V.
 
 # Any import from modelhub initializes all the types, do not remove
 from modelhub import __version__
-from tests_modelhub.functional.modelhub.data_and_utils import get_objectiv_dataframe_test
+from tests_modelhub.data_and_utils.utils import get_objectiv_dataframe_test
 from tests.functional.bach.test_data_and_utils import assert_equals_data
 
-def test_frequency():
-    df, modelhub = get_objectiv_dataframe_test()
+
+def test_frequency(db_params):
+    df, modelhub = get_objectiv_dataframe_test(db_params)
     s = modelhub.aggregate.frequency(df)
 
     assert_equals_data(
